==> custom_route_transition_jaag-0.0.1.tar.gz: lib/custom_route_transition_jaag.dart <==
import 'package:flutter/material.dart';

enum AnimationType { normal, fadeIn }

class CustomTransition {
  final BuildContext _context;
  final Widget _child;
  final AnimationType _animationType;
  final Duration _duration;
  final bool _withReplacement;

  CustomTransition(
    {
      @required BuildContext context,
      @required Widget child,
      AnimationType animationType,
      Duration duration,
      bool withReplacement})
      : _context = context,
        _child = child,
        _animationType = animationType ?? AnimationType.normal,
        _duration = duration ?? Duration(milliseconds: 500),
        _withReplacement = withReplacement ?? false {
    switch (animationType) {
      case AnimationType.normal:
        _applyNormalTransition();
        break;
      case AnimationType.fadeIn:
        _applyFadeInTransition();
        break;
    }
  }

  void _applyNormalTransition() {
    if (_withReplacement) {
      Navigator.pushReplacement(
          _context, MaterialPageRoute(builder: (_) => _child));
    } else {
      Navigator.push(_context, MaterialPageRoute(builder: (_) => _child));
    }
  }

  void _applyFadeInTransition() {
    final PageRouteBuilder route = PageRouteBuilder(
        pageBuilder: (_, __, ___) => _child,
        transitionDuration: _duration,
        transitionsBuilder: (_, animation, ___, child) {
          return FadeTransition(
            child: _child,
            opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
                CurvedAnimation(parent: animation, curve: Curves.easeOut)),
          );
        });
    if (_withReplacement)
      Navigator.pushReplacement(_context, route);
    else
      Navigator.push(_context, route);
  }
}

==> custom_route_transition_jaag-0.0.2.tar.gz: lib/custom_route_transition_jaag.dart <==
import 'package:flutter/material.dart';

enum AnimationType { normal, fadeIn }

class CustomTransition {
  final BuildContext _context;
  //el widget al que se quiere navegar
  final Widget _child;
  final AnimationType _animationType;
  final Duration _duration;
  //el cambio de ruta se hará reemplazando la pila de rutas
  final bool _withReplacement;

  CustomTransition(
      {@required BuildContext context,
      @required Widget child,
      AnimationType animationType,
      Duration duration,
      bool withReplacement})
      : _context = context,
        _child = child,
        _animationType = animationType ?? AnimationType.normal,
        _duration = duration ?? Duration(milliseconds: 500),
        _withReplacement = withReplacement ?? false {
    switch (_animationType) {
      case AnimationType.normal:
        _applyNormalTransition();
        break;
      case AnimationType.fadeIn:
        _applyFadeInTransition();
        break;
    }
  }

  void _applyNormalTransition() {
    if (_withReplacement) {
      Navigator.pushReplacement(
          _context, MaterialPageRoute(builder: (_) => _child));
    } else {
      Navigator.push(_context, MaterialPageRoute(builder: (_) => _child));
    }
  }

  void _applyFadeInTransition() {
    final PageRouteBuilder route = PageRouteBuilder(
        pageBuilder: (_, __, ___) => _child,
        transitionDuration: _duration,
        transitionsBuilder: (_, animation, ___, child) {
          return FadeTransition(
            child: _child,
            opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
                CurvedAnimation(parent: animation, curve: Curves.easeOut)),
          );
        });
    if (_withReplacement)
      Navigator.pushReplacement(_context, route);
    else
      Navigator.push(_context, route);
  }
}
